;; Generated package description from auctex-label-numbers.el  -*- no-byte-compile: t -*-
(define-package "auctex-label-numbers" "0.2" "Numbering for LaTeX previews and folds" '((emacs "27.1") (auctex "14.0.5")) :commit "202e49bb9f754bc647deb112bd2c35f9a583b942" :authors '(("Paul D. Nelson" . "nelson.paul.david@gmail.com")) :maintainer '("Paul D. Nelson" . "nelson.paul.david@gmail.com") :keywords '("tex") :url "https://github.com/ultronozm/auctex-label-numbers.el")
